@@ -43,22 +43,13 @@ typedef struct {
 #define SOUP_ADDRESS_PHYSICAL "physical"
 #define SOUP_ADDRESS_SOCKADDR "sockaddr"
 
-/* gtk-doc gets confused if there's an #ifdef inside the typedef */
-#ifndef AF_INET6
-#define AF_INET6 -1
-#endif
-
 typedef enum {
 	SOUP_ADDRESS_FAMILY_INVALID = -1,
 
-	SOUP_ADDRESS_FAMILY_IPV4 = AF_INET,
-	SOUP_ADDRESS_FAMILY_IPV6 = AF_INET6
+	SOUP_ADDRESS_FAMILY_IPV4 = G_SOCKET_FAMILY_IPV4,
+	SOUP_ADDRESS_FAMILY_IPV6 = G_SOCKET_FAMILY_IPV6
 } SoupAddressFamily;
 
-#if AF_INET6 == -1
-#undef AF_INET6
-#endif
-
 #define SOUP_ADDRESS_ANY_PORT 0
 
 typedef void   (*SoupAddressCallback)            (SoupAddress         *addr,
@@ -87,6 +78,7 @@ const char      *soup_address_get_physical       (SoupAddress         *addr);
 guint            soup_address_get_port           (SoupAddress         *addr);
 struct sockaddr *soup_address_get_sockaddr       (SoupAddress         *addr,
 						  int                 *len);
+GSocketAddress  *soup_address_get_gsockaddr      (SoupAddress         *addr);
 gboolean         soup_address_is_resolved        (SoupAddress         *addr);
 
 guint            soup_address_hash_by_name       (gconstpointer        addr);
